@@ -58,7 +58,7 @@ struct ColorSettings {
 
 QString contactsToHtml(const KContacts::Addressee::List &contacts, const ColorSettings &settings)
 {
-    QString content = QLatin1String("<html>\n");
+    QString content = QStringLiteral("<html>\n");
     content += QLatin1String(" <head>\n");
     content += QLatin1String("  <style type=\"text/css\">\n");
     content += QLatin1String("    td.indented {\n");
@@ -71,14 +71,14 @@ QString contactsToHtml(const KContacts::Addressee::List &contacts, const ColorSe
     for (const KContacts::Addressee &contact : contacts) {
         QString name = contact.realName();
         if (!contact.title().isEmpty() || !contact.role().isEmpty()) {
-            QStringList content;
+            QStringList contentAddress;
             if (!contact.title().isEmpty()) {
-                content << contact.title();
+                contentAddress << contact.title();
             }
             if (!contact.role().isEmpty()) {
-                content << contact.role();
+                contentAddress << contact.role();
             }
-            name += QStringLiteral(" (%1)").arg(content.join(QStringLiteral(", ")));
+            name += QStringLiteral(" (%1)").arg(contentAddress.join(QStringLiteral(", ")));
         }
 
         const QString birthday = QLocale().toString(contact.birthday().date(), QLocale::ShortFormat);
